summaryrefslogtreecommitdiff
path: root/example_create.sh
diff options
context:
space:
mode:
authorOscar Benedito <oscar@oscarbenedito.com>2020-06-20 02:16:34 +0200
committerOscar Benedito <oscar@oscarbenedito.com>2020-06-22 22:06:27 +0200
commit3c1a822f60e08f2ad2f9920984b5d7f948367101 (patch)
tree16dd15a63f09f89be70b7bf3b71b595be4359f33 /example_create.sh
parent467dfeb8f4bf2dd1ddb69e5c9592147acb425aab (diff)
favicon: png to ico
Diffstat (limited to 'example_create.sh')
-rwxr-xr-xexample_create.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/example_create.sh b/example_create.sh
index cf16e1d..e1adbe1 100755
--- a/example_create.sh
+++ b/example_create.sh
@@ -3,7 +3,7 @@
# - Makes static pages for each repository directory.
#
# NOTE, things to do manually (once) before running this script:
# - copy style.css, logo.png and favicon.png manually, a style.css example
# is included.
#
# - write clone url, for example "git://git.codemadness.org/dir" to the "url"
@@ -37,7 +37,7 @@ for dir in "${reposdir}/"*/; do
ln -sf log.html index.html
ln -sf ../style.css style.css
ln -sf ../logo.png logo.png
- ln -sf ../favicon.png favicon.png
+ ln -sf ../favicon.ico favicon.ico
echo "done"
done
@@ -3,7 +3,7 @@
#
# NOTE, things to do manually (once) before running this script:
-# - copy style.css, logo.png and favicon.png manually, a style.css example
+# - copy style.css, logo.png and favicon.ico manually, a style.css example
# is included.
#